# package_name

Description. 
The package factorial is used to:
	calculo:
	- calculo fatorial
	saída:
	- f
	

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install factorial
```

## Author
Fabricio

## License
[MIT](https://choosealicense.com/licenses/mit/)